pub struct SecretVerificationRequest {
pub master_password: Option<String>,
pub otp: Option<String>,
}Expand description
Request to verify a user’s secret.
Fields
master_password: Option<String>The user’s master password to use for user verification. If supplied, this will be used for verification purposes.
otp: Option<String>Alternate user verification method through OTP. This is provided for users who have no master password due to use of Customer Managed Encryption. Must be present and valid if master_password is absent.