pub struct StateClient {
pub(crate) client: Client,
}Expand description
Wrapper for state specific functionality.
Fields
client: ClientImplementations
Sourceimpl StateClient
impl StateClient
Sourcepub fn register_client_managed<T: 'static + Repository<V>, V: RepositoryItem>(
&self,
store: Arc<T>,
)
pub fn register_client_managed<T: 'static + Repository<V>, V: RepositoryItem>( &self, store: Arc<T>, )
Register a client managed state repository for a specific type.
Sourcepub async fn initialize_database(
&self,
configuration: DatabaseConfiguration,
migrations: RepositoryMigrations,
) -> Result<(), StateRegistryError>
pub async fn initialize_database( &self, configuration: DatabaseConfiguration, migrations: RepositoryMigrations, ) -> Result<(), StateRegistryError>
Initialize the database for SDK managed repositories.
Sourcepub fn get<T>(&self) -> Result<Arc<dyn Repository<T>>, StateRegistryError>where
T: RepositoryItem,
pub fn get<T>(&self) -> Result<Arc<dyn Repository<T>>, StateRegistryError>where
T: RepositoryItem,
Get a repository with fallback: prefer client-managed, fall back to SDK-managed.
This method first attempts to retrieve a client-managed repository. If not registered,
it falls back to an SDK-managed repository. Both are returned as Arc<dyn Repository<T>>.
Errors
Returns StateRegistryError when neither repository type is available.
Sourcepub fn setting<T>(&self, key: Key<T>) -> Result<Setting<T>, SettingsError>
pub fn setting<T>(&self, key: Key<T>) -> Result<Setting<T>, SettingsError>
Get a handle to a setting by its type-safe key.
Returns a Setting handle that can be used to get, update, or delete the value.
Example
use bitwarden_state::register_setting_key;
use serde::{Deserialize, Serialize};
#[derive(Serialize, Deserialize)]
struct AppConfig {
theme: String,
}
register_setting_key!(const CONFIG: AppConfig = "app_config");
let setting = client.platform().state().setting(CONFIG)?;
let value: Option<AppConfig> = setting.get().await?;Auto Trait Implementations
impl Freeze for StateClient
impl !RefUnwindSafe for StateClient
impl Send for StateClient
impl Sync for StateClient
impl Unpin for StateClient
impl UnsafeUnpin for StateClient
impl !UnwindSafe for StateClient